<!DOCTYPE style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN">

;; Print stylesheet
;; This should work for TeX/DVI/PDF/PS/RTF and family
;; <!-- $Fuller: sgml/resume/dsssl/print.dsl,v 1.2 2002/01/03 07:18:56 fullermd Exp $ -->

;; First, define some stuff
(declare-initial-value font-family-name "serif")
(declare-initial-value font-size 14pt)
(declare-initial-value min-leading 0pt)

;; Some useful vars
(define %default-margin% 1in)
(define %default-fontsize% 14pt)
(define %empty-line% (* %default-fontsize% .75))
(define %fsize-heading% (* %default-fontsize% 1.5))
(define %fsize-subheading% (* %default-fontsize% 1.25))
(define %fsize-subsub% (* %default-fontsize% 1.2))
(define %fixed-font% "Courier")
;; This is necessary as otherwise it overpowers the default
(define %fixed-fsize% (* %default-fontsize% .9))


;; Now, work from the outside-in
(element resume
	(make simple-page-sequence
		left-margin: %default-margin%
		right-margin: %default-margin%
		top-margin: %default-margin%
		bottom-margin: %default-margin%
		(process-children)))

;; 'heading' section
(element heading
	(make display-group
		(process-children)))

(element (heading fullname)
	(make paragraph
		space-after: %empty-line%
		font-size: (* %fsize-heading% 1.5)
		font-weight: 'bold
		quadding: 'center
		(process-children)))

(element (heading address)
	(make display-group
		(make paragraph
			space-before: (* %empty-line% .2)
			space-after: (* %empty-line% .2)
			font-size: %fsize-subheading%
			font-weight: 'bold
			keep-with-next?: #t
			quadding: 'center
			(process-matching-children 'street))
		(make paragraph
			space-after: (* %empty-line% .5)
			font-size: %fsize-subheading%
			font-weight: 'bold
			keep-with-next?: #t
			quadding: 'center
			(process-matching-children 'city 'state 'zip))
		(make paragraph
			space-after: (* %empty-line% .5)
			font-size: %fsize-subheading%
			font-weight: 'bold
			keep-with-next?: #t
			quadding: 'center
			(process-matching-children 'phone))
		(make paragraph
			space-after: (* %empty-line% .2)
			font-size: %fsize-subheading%
			font-weight: 'bold
			keep-with-next?: #t
			quadding: 'center
			(process-matching-children 'email))
		(make paragraph
			space-after: (* %empty-line% .2)
			font-size: %fsize-subheading%
			font-weight: 'bold
			keep-with-next?: #t
			quadding: 'center
			(process-matching-children 'url))))


;; 'objective' is easy
(element objective
	(make display-group
		(make paragraph
			font-size: %fsize-heading%
			font-weight: 'bold
			keep-with-next?: #t
			space-before: (* %empty-line% 2)
			space-after: %empty-line%
;; We need to find a way to number these sections
;;			(literal (format-number (child-number) "I"))
			(literal "- Objective"))
		(process-children)))

(element (objective para)
	(make paragraph
		start-indent: 20pt
		(process-children)))

;; 'workhist' section
(element workhist
	(make display-group
		(make paragraph
			font-size: %fsize-heading%
			font-weight: 'bold
			keep-with-next?: #t
			space-before: (* %empty-line% 2)
;; We need to find a way to number these sections
;;			(literal (format-number (child-number) "I"))
			(literal "- Work history"))
		(process-children)))

(element (workhist job)
	(make display-group
		(make paragraph
			font-size: %fsize-subheading%
			font-weight: 'bold
			start-indent: 50pt
			first-line-start-indent: -30pt
			space-before: %empty-line%
			keep-with-next?: #t
			(literal (format-number (child-number) "1"))
			(literal "- ")
			(process-matching-children 'company))
		(make paragraph
			start-indent: 40pt
			space-before: (* %empty-line% .25)
			(make paragraph
				font-size: %fsize-subsub%
				font-weight: 'bold
				keep-with-next?: #t
				(literal "Address: "))
			(make paragraph
				space-before: (* %empty-line% .1)
				(process-matching-children 'address)))
		(make paragraph
			start-indent: 40pt
			space-before: (* %empty-line% .25)
			keep-with-next?: #t
			(make sequence
				font-size: %fsize-subsub%
				font-weight: 'bold
				(literal "Employment period: "))
			(make sequence
				(process-matching-children 'startdate 'enddate)))
		(make paragraph
			start-indent: 50pt
			first-line-start-indent: -10pt
			space-before: (* %empty-line% .25)
			(make paragraph
				font-size: %fsize-subsub%
				font-weight: 'bold
				keep-with-next?: #t
				(literal "Responsibilities: "))
			(make sequence
				(process-matching-children 'responsibilities)))))

;; This is used by 'job', 'education', and 'references'
(element address
	(make display-group
		start-indent: 50pt
		(make paragraph
			keep-with-next?: #t
			(process-matching-children 'street))
		(make paragraph
			keep-with-next?: #t
			(process-matching-children 'city 'state 'zip))
		(make paragraph
			keep-with-next?: #t
			(process-matching-children 'phone))
		(make paragraph
			keep-with-next?: #t
			(process-matching-children 'email))
		(make paragraph
			keep-with-next?: #t
			(process-matching-children 'url))))

(element (job company)
	(make sequence
		(process-children)))

(element startdate
	(make sequence
		(process-children)
		(literal " - ")))

(element enddate
	(make sequence
		(process-children)))

(element (job responsibilities)
	(make paragraph
		start-indent: 50pt
		first-line-start-indent: 10pt
		(process-children)))


;; 'experience' section
(element experience
	(make display-group
		(make paragraph
			font-size: %fsize-heading%
			font-weight: 'bold
			space-before: (* %empty-line% 2)
			keep-with-next?: #t
			(literal "- ")
			(process-matching-children 'type)
			(literal " experience"))
		(make paragraph
			(process-matching-children 'category))))

(element type
	(make sequence
		(process-children)))

(element (experience category)
	(make display-group
		(make paragraph
			font-size: %fsize-subheading%
			font-weight: 'bold
			start-indent: 50pt
			first-line-start-indent: -30pt
			space-before: %empty-line%
			keep-with-next?: #t
			(literal "-  ")
			(process-matching-children 'type))
		(make paragraph
			space-before: %empty-line%
			(process-matching-children 'tidbit))))

(element (category tidbit)
	(make paragraph
		start-indent: 50pt
		first-line-start-indent: -20pt
		(process-children)))

(element (tidbit para)
	(make paragraph
		space-before: (* %empty-line% .3)
		(literal "*  ")
		(process-children)))

;; Edumakayshun
(element education
	(make display-group
		(make paragraph
			font-size: %fsize-heading%
			font-weight: 'bold
			space-before: (* %empty-line% 2)
			keep-with-next?: #t
			(literal "- Education"))
		(make paragraph
			(process-children))))

(element (education institute)
	(make display-group
		(make paragraph
			font-size: %fsize-subheading%
			font-weight: 'bold
			start-indent: 50pt
			first-line-start-indent: -30pt
			space-before: %empty-line%
			keep-with-next?: #t
			(literal "-  ")
			(process-matching-children 'name))
		(make paragraph
			start-indent: 40pt
			space-before: (* %empty-line% .25)
			(make paragraph
				font-size: %fsize-subsub%
				font-weight: 'bold
				keep-with-next?: #t
				(literal "Address: "))
			(make paragraph
				space-before: (* %empty-line% .1)
				(process-matching-children 'address)))
		(make paragraph
			start-indent: 40pt
			space-before: (* %empty-line% .25)
			(make sequence
				font-size: %fsize-subsub%
				font-weight: 'bold
				(literal "Attended: "))
			(make sequence
				(process-matching-children 'startdate 'enddate)))
		(make paragraph
			start-indent: 50pt
			first-line-start-indent: -10pt
			space-before: (* %empty-line% .25)
			(make paragraph
				font-size: %fsize-subsub%
				font-weight: 'bold
				keep-with-next?: #t
				(literal "Details: "))
			(make paragraph
				(process-matching-children 'details)))))

(element (institute details)
	(make paragraph
		start-indent: 50pt
		first-line-start-indent: -10pt
		(process-children)))

(element (details para)
	(make paragraph
		space-before: (* %empty-line% .3)
		(literal "*  ")
		(process-children)))

(element name
	(make sequence
		(process-children)))


;; And the references section
(element references
	(make display-group
		(make paragraph
			font-size: %fsize-heading%
			font-weight: 'bold
			space-before: (* %empty-line% 2)
			keep-with-next?: #t
			(literal "- References"))
		(if (equal? (attribute-string "ONREQUEST") "YES")
			(make paragraph
				font-size: %fsize-subheading%
				font-weight: 'bold
				start-indent: 50pt
				first-line-start-indent: -30pt
				space-before: %empty-line%
				(literal "References are available upon request."))
			(make display-group
				(process-children)))))

(element reference
	(make display-group
		(make paragraph
			font-size: %fsize-subheading%
			font-weight: 'bold
			start-indent: 50pt
			first-line-start-indent: -30pt
			space-before: %empty-line%
			keep-with-next?: #t
			(literal "-  ")
			(process-matching-children 'name))
		(make paragraph
			start-indent: 40pt
			space-before: (* %empty-line% .25)
			(make paragraph
				font-size: %fsize-subsub%
				font-weight: 'bold
				keep-with-next?: #t
				(literal "Address: "))
			(make paragraph
				space-before: (* %empty-line% .1)
				(process-matching-children 'address)))
		(make paragraph
			start-indent: 50pt
			first-line-start-indent: -10pt
			space-before: (* %empty-line% .25)
			(make paragraph
				font-size: %fsize-subsub%
				font-weight: 'bold
				keep-with-next?: #t
				(literal "Relationship: "))
			(make paragraph
				(process-matching-children 'relationship)))
		(make paragraph
			start-indent: 50pt
			first-line-start-indent: -10pt
			space-before: (* %empty-line% .25)
			(make sequence
				(process-matching-children 'details)))))

(element (reference relationship)
	(make sequence
		(process-children)))

(element (reference details)
	(make paragraph
		start-indent: 50pt
		first-line-start-indent: -10pt
		(process-children)))



;; address subelements
(element (address street)
	(make sequence
		(process-children)))

(element (address city)
	(make sequence
		(process-children)
		(literal ", ")))

(element (address state)
	(make sequence
		(process-children)
		(literal "     ")))

(element (address zip)
	(make sequence
		(process-children)))

(element (address phone)
	(make sequence
		font-family-name: %fixed-font%
		font-size: %fixed-fsize%
		(process-children)))

(element (address email)
	(make sequence
		font-family-name: %fixed-font%
		font-size: %fixed-fsize%
		(process-children)))

(element (address url)
	(make sequence
		font-family-name: %fixed-font%
		font-size: %fixed-fsize%
		(process-children)))

;; Other tiny things
(element para
	(make paragraph
		(process-children)))

(element br
	(make display-group
		(empty-sosofo)))

(element href
	(make sequence
		(make sequence
			(process-children)
			(literal " ("))
		(make sequence
			font-family-name: %fixed-font%
			font-size: %fixed-fsize%
			(literal (attribute-string "url")))
		(make sequence
			(literal ")"))))
